@@ -1,5 +1,5 @@
 ## File Name: mdmb_regression_loglike_logpost.R
-## File Version: 0.15
+## File Version: 0.24
 
 mdmb_regression_loglike_logpost <- function(mod, beta, beta_prior, is_prior, type,
         is_lambda_fixed)
@@ -14,7 +14,9 @@ mdmb_regression_loglike_logpost <- function(mod, beta, beta_prior, is_prior, typ
     hessian <- mod$hessian
     parnames <- names(beta)
     np <- length(beta)
-    vcov1 <- MASS::ginv(hessian)
+    # hessian <- ( hessian + t(hessian) ) / 2
+    vcov1 <- MASS::ginv(X=hessian)
+    #vcov1 <- mdmb_ginv(x=hessian)
     if ( ( type %in% c("yjt","bct") ) & ( is_lambda_fixed ) ){
         vcov0 <- matrix( 0, nrow=np, ncol=np )
         vcov0[1:(np-1),1:(np-1)] <- vcov1
